@@ -1,8 +1,8 @@
-__version__ = '1.7.12'
+__version__ = '1.8.0'
 
 import logging
 
-logging.basicConfig()
+#logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 from .interface import (Contract, ContractNotRespected,
